-- FuBar_HealBotFu: Simple FuBar plugin for HealBot.
-- Copyright (C) 2008  Justin Weaver (Visit http://piramod.com for contact)
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.

HealBotFu = AceLibrary("AceAddon-2.0"):new("AceDB-2.0", "AceConsole-2.0", "FuBarPlugin-2.0");

local tablet = AceLibrary("Tablet-2.0");

--
-- FuBar Options
HealBotFu.defaultPosition = "LEFT";
HealBotFu.hasIcon = "Interface\\AddOns\\FuBar_HealBotFu\\icon";
HealBotFu.defaultMinimapPosition = 317;
HealBotFu.cannotDetachTooltip = true;
HealBotFu.hideWithoutStandby = true;
HealBotFu.independentProfile = true;
HealBotFu.hasNoText = true;
HealBotFu.hideMenuTitle = true;

local defaults = {
   hideOldHealBotMinimapButton = true,
};

HealBotFu.options = {
   type = "group",
   args = {
      ["hideOldHealBotMinimapButton"] = {
	 name = "Hide HealBot Icon",
	 type = "toggle",
	 desc = "Hide HealBot's own minimap icon",
	 order = 1,
	 get = function() 
		  return HealBotFu.db.profile.hideOldHealBotMinimapButton;
	       end,
	 set = function(v) 
		  HealBotFu.db.profile.hideOldHealBotMinimapButton = v;
		  HealBotFu:HideOldHealBotMinimapButton();
	       end,
	 usage = "Enabling this will automatically hide the minimap button that HealBot provides.",
      },
   },
};
HealBotFu.OnMenuRequest = HealBotFu.options;

HealBotFu:RegisterChatCommand({ "/healbotfu" }, HealBotFu.options);

HealBotFu:RegisterDB("HealBotFuDB");
HealBotFu:RegisterDefaults('profile', defaults);

local _G = getfenv(0);

function HealBotFu:OnClick()
   if ( IsShiftKeyDown() ) then
      _G.HealBot_SetResetFlag("SOFT");
   else
      _G.HealBot_ToggleOptions();
   end
end

function HealBotFu:HideOldHealBotMinimapButton()
   if ( self.db.profile.hideOldHealBotMinimapButton ) then
      -- hide healbot's regular icon
      _G.HealBot_Options_ShowMinimapButton:SetChecked(false);
      _G.HealBot_Config.ButtonShown = 0;
   else
      -- show it
      _G.HealBot_Options_ShowMinimapButton:SetChecked(true);
      _G.HealBot_Config.ButtonShown = 1;
   end
   _G.HealBot_MMButton_Init();
end

function HealBotFu:OnEnable()
   self:HideOldHealBotMinimapButton();
end

function HealBotFu:OnTooltipUpdate()
   tablet:SetHint("Left-Click to open HealBot options.  Shift-Left-Click to reset HealBot.  Right-Click for menu.");
end
